@@ -4,7 +4,7 @@ test_that("can make simple request", {
   chat <- chat_cloudflare_test("Be as terse as possible; no punctuation")
   resp <- chat$chat("What is 1 + 1?", echo = FALSE)
   expect_match(resp, "2")
-  expect_equal(chat$last_turn()@tokens > 0, c(TRUE, TRUE))
+  expect_equal(chat$last_turn()@tokens[1:2] > 0, c(TRUE, TRUE))
 })
 
 test_that("can make simple streaming request", {
@@ -27,7 +27,7 @@ test_that("defaults are reported", {
 # })
 
 # Doesn't appear to work
-# test_that("all tool variations work", {
+# test_that("supports tool calling", {
 #   chat_fun <- function(...) {
 #     chat_cloudflare_test(
 #       ...,
@@ -36,9 +36,6 @@ test_that("defaults are reported", {
 #   }
 
 #   test_tools_simple(chat_fun)
-#   test_tools_async(chat_fun)
-#   test_tools_parallel(chat_fun)
-#   test_tools_sequential(chat_fun, total_calls = 6)
 # })
 
 test_that("can extract data", {
