@@ -7,7 +7,7 @@ test_that("can make simple request", {
   )
   resp <- chat$chat("What is 1 + 1?", echo = FALSE)
   expect_match(resp, "2")
-  expect_equal(chat$last_turn()@tokens > 0, c(TRUE, TRUE))
+  expect_equal(chat$last_turn()@tokens[1:2] > 0, c(TRUE, TRUE))
 })
 
 test_that("can make simple streaming request", {
@@ -25,15 +25,12 @@ test_that("defaults are reported", {
   expect_snapshot(. <- chat_portkey())
 })
 
-test_that("all tool variations work", {
+test_that("supports tool calling", {
   chat_fun <- \(...) {
     chat_portkey_test(virtual_key = Sys.getenv("PORTKEY_VIRTUAL_KEY"))
   }
 
   test_tools_simple(chat_fun)
-  test_tools_async(chat_fun)
-  test_tools_parallel(chat_fun)
-  test_tools_sequential(chat_fun, total_calls = 6)
 })
 
 test_that("can extract data", {
